@@ -528,7 +528,7 @@ impl<'a> scroll::ctx::TryFromCtx<'a, Endian> for CV_INFO_PDB70 {
 /// ```
 /// use minidump_common::format::GUID;
 ///
-/// let guid = GUID { data1: 10, data2: 11, data3: 12, data4: [1,2,3,4,5,6,7,8]};
+/// let guid = GUID { data1: 10, data2: 11, data3: 12, data4: [1,2,3,4,5,6,7,8] };
 ///
 /// // default formatting
 /// assert_eq!("0000000a-000b-000c-0102-030405060708", guid.to_string());
@@ -538,7 +538,7 @@ impl<'a> scroll::ctx::TryFromCtx<'a, Endian> for CV_INFO_PDB70 {
 /// ```
 ///
 /// [msdn]: https://docs.microsoft.com/en-us/windows/win32/api/guiddef/ns-guiddef-guid
-#[derive(Clone, Copy, Debug, PartialEq, Eq, Pread, SizeWith)]
+#[derive(Clone, Copy, Debug, PartialEq, Eq, Pread, Pwrite, SizeWith)]
 pub struct GUID {
     pub data1: u32,
     pub data2: u16,
@@ -546,6 +546,44 @@ pub struct GUID {
     pub data4: [u8; 8],
 }
 
+/// Creates a GUID from a raw byte array. It is assumed that the components in
+/// the array are in big-endian order.
+///
+/// ```
+/// use minidump_common::format::GUID;
+///
+/// let mut buf = [0u8; 16];
+/// buf[0..4].copy_from_slice(&0xdeadc0deu32.to_be_bytes());
+/// buf[4..6].copy_from_slice(&0xb105u16.to_be_bytes());
+/// buf[6..8].copy_from_slice(&0xc0deu16.to_be_bytes());
+/// buf[8..].copy_from_slice(&[1, 2, 3, 4, 5, 6, 7, 8]);
+///
+/// let guid: GUID = buf.into();
+///
+/// let expected = GUID { data1: 0xdeadc0de, data2: 0xb105, data3: 0xc0de, data4: [1, 2, 3, 4, 5, 6, 7, 8] };
+///
+/// assert_eq!(guid, expected);
+/// ```
+impl From<[u8; 16]> for GUID {
+    fn from(uuid: [u8; 16]) -> Self {
+        let data1 = (uuid[0] as u32) << 24
+            | (uuid[1] as u32) << 16
+            | (uuid[2] as u32) << 8
+            | uuid[3] as u32;
+        let data2 = (uuid[4] as u16) << 8 | uuid[5] as u16;
+        let data3 = (uuid[6] as u16) << 8 | uuid[7] as u16;
+        let mut data4 = [0u8; 8];
+        data4.copy_from_slice(&uuid[8..]);
+
+        Self {
+            data1,
+            data2,
+            data3,
+            data4,
+        }
+    }
+}
+
 impl fmt::Display for GUID {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         // NB: This formatting is not endianness aware. GUIDs read from LE minidumps are printed
@@ -683,7 +721,7 @@ pub struct MINIDUMP_EXCEPTION_STREAM {
 /// This struct matches the [Microsoft struct][msdn] of the same name.
 ///
 /// [msdn]: https://docs.microsoft.com/en-us/windows/win32/api/minidumpapiset/ns-minidumpapiset-minidump_exception
-#[derive(Debug, Clone, Pread, Pwrite, SizeWith)]
+#[derive(Debug, Clone, Default, Pread, Pwrite, SizeWith)]
 pub struct MINIDUMP_EXCEPTION {
     /// The reason the exception occurred.
     ///
@@ -1474,7 +1512,7 @@ pub enum PlatformId {
 /// This struct matches the [Microsoft struct][msdn] of the same name.
 ///
 /// [msdn]: https://msdn.microsoft.com/en-us/library/windows/desktop/ms724950(v=vs.85).aspx
-#[derive(Debug, Clone, Default, Pread, SizeWith, PartialEq, Eq)]
+#[derive(Debug, Clone, Default, Pread, Pwrite, SizeWith, PartialEq, Eq)]
 pub struct SYSTEMTIME {
     pub year: u16,
     pub month: u16,
@@ -1491,7 +1529,7 @@ pub struct SYSTEMTIME {
 /// This struct matches the [Microsoft struct][msdn] of the same name.
 ///
 /// [msdn]: https://docs.microsoft.com/en-us/windows/win32/api/timezoneapi/ns-timezoneapi-time_zone_information
-#[derive(Debug, Clone, Default, Pread, SizeWith)]
+#[derive(Debug, Clone, Default, Pread, Pwrite, SizeWith)]
 pub struct TIME_ZONE_INFORMATION {
     pub bias: i32,
     pub standard_name: [u16; 32],
@@ -1518,7 +1556,7 @@ macro_rules! multi_structs {
     // Declare a single struct.
     ($(#[$attr:meta])* pub struct $name:ident { $( pub $field:ident: $t:tt, )* } $($tail:tt)* ) => {
         $(#[$attr])*
-        #[derive(Debug, Clone, Pread, SizeWith)]
+        #[derive(Debug, Clone, Pread, Pwrite, SizeWith)]
         pub struct $name {
             $( pub $field: $t, )*
         }
@@ -1631,7 +1669,7 @@ multi_structs! {
 /// If you want to check for that bit, check the raw value of
 /// [`context_flags`](`CONTEXT_AMD64::context_flags`).
 
-#[derive(Debug, Clone, Pread, SizeWith)]
+#[derive(Debug, Clone, Pread, Pwrite, SizeWith)]
 pub struct XSTATE_CONFIG_FEATURE_MSC_INFO {
     /// The size of this struct.
     pub size_of_info: u32,
@@ -1718,7 +1756,7 @@ impl XstateFeatureIndex {
 }
 
 /// The offset and size of each XSAVE entry inside the XSAVE context.
-#[derive(Clone, Copy, Debug, Default, Pread, SizeWith, PartialEq, Eq)]
+#[derive(Clone, Copy, Debug, Default, Pread, Pwrite, SizeWith, PartialEq, Eq)]
 pub struct XSTATE_FEATURE {
     /// This entry's offset from the start of the context (in bytes).
     ///
@@ -1848,7 +1886,7 @@ bitflags! {
 /// Taken from the definition in Breakpad's [minidump_format.h][fmt].
 ///
 /// [fmt]: https://chromium.googlesource.com/breakpad/breakpad/+/88d8114fda3e4a7292654bd6ac0c34d6c88a8121/src/google_breakpad/common/minidump_format.h#962
-#[derive(Debug, Clone, Pread, SizeWith)]
+#[derive(Debug, Clone, Pread, Pwrite, SizeWith)]
 pub struct MINIDUMP_BREAKPAD_INFO {
     pub validity: u32,
     /// The Thread ID of the handler thread
